@@ -342,302 +342,26 @@ sysfs_devinfo(struct path * curpath)
 			curpath->sg_id.scsi_id,
 			curpath->sg_id.lun);
 
-	return 0;
-}
-
-/*
- * Supported Code Set values.
- */
-#define        CODESET_BINARY  1
-#define        CODESET_ASCII   2
-
-static const char hex_str[]="0123456789abcdef";
-
-/*
- * check_fill_0x83_id - check the page 0x83 id, if OK allocate and fill
- * serial number.
- */
-static int check_0x83_id(char *scsi_dev, char *page_83, int max_len)
-{
-	int i, j, len, idweight;
-
 	/*
-	 * ASSOCIATION must be with the device (value 0)
+	 * target node name
 	 */
-	if ((page_83[1] & 0x30) != 0)
-		return -1;
-
-	/*
-	 * Check for code set - ASCII or BINARY.
-	 */
-	dbg("%s: Codeset: %X", scsi_dev, page_83[0] & 0x0f);
-	if (((page_83[0] & 0x0f) != CODESET_ASCII) &&
-	    ((page_83[0] & 0x0f) != CODESET_BINARY))
-		return -1;
-
-	/*
-	 * Check for ID type
-	 */
-	idweight = page_83[1] & 0x0f;
-	
-#if DEBUG
-	fprintf(stdout,"%s: ID type: ", scsi_dev);
-	switch (page_83[1] & 0x0f) {
-	case 0x0:
-		printf("Vendor specific\n");
-		break;
-	case 0x1:
-		printf("T-10 vendor identification\n");
-		break;
-	case 0x2:
-		printf("EUI-64\n");
-		break;
-	case 0x3:
-		printf("NAA ");
-		switch((page_83[4] >> 4) & 0x0f) {
-		case 0x02:
-			printf("IEEE Extended\n");
-			break;
-		case 0x05:
-			printf("IEEE Registered\n");
-			break;
-		case 0x06:
-			printf("IEEE Registered Extended\n");
-			break;
-		default:
-			printf("Reserved (%X)\n", (page_83[4] >> 4) & 0x0f);
-			break;
-		}
-		break;
-	case 0x4:
-		printf("Relative target port\n");
-		break;
-	case 0x5:
-		printf("Target port group\n");
-		break;
-	case 0x6:
-		printf("Logical unit group\n");
-		break;
-	case 0x7:
-		printf("MD5 logical unit identifier\n");
-		break;
-	default:
-		printf("Reserved\n");
-		break;
-	}
-#endif
-	/*
-	 * Only allow vendor specific, T-10 Vendor Identifcation,
-	 * EUI-64 or NAA identificators
-	 */
-	if ((page_83[1] & 0x0f) > 0x3)
-		return -1;
-
-	/*
-	 * Prefer NAA Registered Extended to NAA Registered and
-	 * NAA Extended.
-	 * Not checking for actual NAA types as some devices
-	 * ( e.g. Compaq iSCSI disks via CISCO routers) return
-	 * add NAA subtypes (0x3).
-	 */
-	if ((page_83[1] & 0x0f) == 0x03) {
-		idweight += (page_83[4] >> 4) & 0x0f;
-
-	}
-
-	/*
-	 * page_83[3]: identifier length
-	 */
-	len = page_83[3];
-	if ((page_83[0] & 0x0f) != CODESET_ASCII)
-		/*
-		 * If not ASCII, use two bytes for each binary value.
-		 */
-		len *= 2;
-	/*
-	 * Add one byte for the NULL termination.
-	 */
-	if (max_len < len + 1) {
-		fprintf(stderr, "%s: length %d too short - need %d\n",
-			scsi_dev, max_len, len);
+	if(safe_sprintf(attr_path,
+			"%s/class/fc_transport/target%i:%i:%i/node_name",
+			sysfs_path,
+			curpath->sg_id.host_no,
+			curpath->sg_id.channel,
+			curpath->sg_id.scsi_id)) {
+		fprintf(stderr, "attr_path too small\n");
 		return 1;
 	}
-
-	i = 4; /* offset to the start of the identifier */
-	j = 0;
-
-	if ((page_83[0] & 0x0f) == CODESET_ASCII) {
-		/*
-		 * ASCII descriptor.
-		 *
-		 * Check whether the descriptor contains anything useful
-		 * i.e. anything apart from ' ' or '0'.
-		 */
-#if DEBUG
-		fprintf(stdout,"%s: string '", scsi_dev);
-#endif
-		while (i < (4 + page_83[3])) {
-			if (page_83[i] == ' ' || page_83[i] == '0')
-				len--;
-#if DEBUG
-			fputc(page_83[i],stdout);
-#endif
-			i++;
-		}
-#if DEBUG
-		fprintf(stdout,"'");
-#endif
-	} else {
-		/*
-		 * Binary descriptor, convert to ASCII, using two bytes of
-		 * ASCII for each byte in the page_83.
-		 *
-		 * Again, check whether the descriptor contains anything
-		 * useful; in this case, anything > 0.
-		 */
-#if DEBUG
-		fprintf(stdout,"%s: binary ", scsi_dev);
-#endif
-		while (i < (4 + page_83[3])) {
-			if (page_83[i] == 0)
-				len-=2;
-#if DEBUG
-			fputc(hex_str[(page_83[i] & 0xf0) >> 4],stdout);
-			fputc(hex_str[page_83[i] & 0x0f],stdout);
-#endif
-			i++;
-		}
-	}
-	dbg(" (len %d)", len);
-
-	if (len <= 0)
-		return -1;
-
-	return idweight;
-}
-
-/*
- * fill_0x83_id - fill serial number.
- */
-static int fill_0x83_id(char *page_83, char *serial)
-{
-	int i, j, len;
-
-	/*
-	 * page_83[3]: identifier length
-	 */
-	len = page_83[3];
-	if ((page_83[0] & 0x0f) != CODESET_ASCII)
-		/*
-		 * If not ASCII, use two bytes for each binary value.
-		 */
-		len *= 2;
-
-	/*
-	 * Add one byte for the NULL termination.
-	 */
-	len += 1;
-
-	i = 4; /* offset to the start of the identifier */
-	j = 0;
-
-	if ((page_83[0] & 0x0f) == CODESET_ASCII) {
-		/*
-		 * ASCII descriptor.
-		 */
-		while (i < (4 + page_83[3])) {
-			/* Map ' ' -> '_' */
-			if (page_83[i] == ' ')
-				serial[j] = '_';
-			else
-				serial[j] = page_83[i];
-			j++; i++;
-		}
-	} else {
-		/*
-		 * Binary descriptor, convert to ASCII, using two bytes of
-		 * ASCII for each byte in the page_83.
-		 */
-		while (i < (4 + page_83[3])) {
-			serial[j++] = hex_str[(page_83[i] & 0xf0) >> 4];
-			serial[j++] = hex_str[page_83[i] & 0x0f];
-			i++;
-		}
-	}
-	return 0;
-}
-
-#if 0
-unsigned long
-get_disk_size (char * devname) {
-	unsigned long size;
-	char attr_path[FILE_NAME_SIZE];
-	char sysfs_path[FILE_NAME_SIZE];
-	char buff[FILE_NAME_SIZE];
-
-	if (0 == sysfs_get_mnt_path(sysfs_path, FILE_NAME_SIZE)) {
-		memset(attr_path, 0, FILE_NAME_SIZE);
-		if(safe_sprintf(attr_path, "%s/block/%s/size",
-			sysfs_path, devname)) {
-			fprintf(stderr, "attr_path too small\n");
-			return -1;
-		}
-		if (0 > sysfs_read_attribute_value(attr_path, buff,
-			FILE_NAME_SIZE))
-			return -1;
-		size = strtoul(buff, NULL, 10);
-		return size;
-	}
-	dbg("get_disk_size need sysfs");
-	return -1;
-}
-#endif
-
-/*
- * get EVPD page 0x83 off 8
- * tested ok with StorageWorks
- */
-int
-get_evpd_wwid (char * dev_t, char * wwid)
-{
-        int fd, j, weight, weight_cur, offset_cur, retval = 0;
-        char buff[MX_ALLOC_LEN + 1];
-
-	fd = opennode(dev_t, O_RDONLY);
-
-        if (fd < 0)
+	if (0 > readattr(attr_path, attr_buff))
 		return 1;
+	if (strlen(attr_buff) > 0)
+		strncpy(curpath->tgt_node_name, attr_buff,
+			strlen(attr_buff) - 1);
+	dbg("tgt_node_name = %s", curpath->tgt_node_name);
 
-	weight_cur = -1;
-	offset_cur = -1;
-
-        if (0 == do_inq(fd, 0, 1, 0x83, buff, MX_ALLOC_LEN, 1)) {
-		/*
-		 * Examine each descriptor returned. There is normally only
-		 * one or a small number of descriptors.
-		 */
-		for (j = 4; j <= buff[3] + 3; j += buff[j + 3] + 4) {
-#if DEBUG
-			fprintf(stdout,"%s: ID descriptor at %d:\n", 
-				dev_t, j);
-#endif
-			weight = check_0x83_id(dev_t, &buff[j], 
-					       MX_ALLOC_LEN);
-			if (weight >= 0 && weight > weight_cur) {
-				weight_cur = weight;
-				offset_cur = j;
-			}
-		}
-
-		if (weight_cur >= 0)
-			fill_0x83_id(&buff[offset_cur], wwid);
-		else
-			retval = 1;
-	} else
-		retval = 1;
-
-	closenode(dev_t, fd);
-        return retval;
+	return 0;
 }
 
 static char *
@@ -763,22 +487,13 @@ devinfo (struct path *pp)
 	 * get path uid
 	 */
 	select_getuid(pp);
-
 	buff = apply_format(pp->getuid, CALLOUT_MAX_SIZE, pp);
 
-	if (!buff)
-		goto fallback;
-
-	if (execute_program(buff, pp->wwid, WWID_SIZE) == 0) {
+	if (buff && execute_program(buff, pp->wwid, WWID_SIZE) == 0) {
 		dbg("uid = %s (callout)", pp->wwid);
 		return 0;
 	}
 
-	fallback:
-	if (!get_evpd_wwid(pp->dev_t, pp->wwid)) {
-		dbg("uid = %s (internal getuid)", pp->wwid);
-		return 0;
-	}
 	/*
 	 * no wwid : blank for safety
 	 */
