@@ -25,7 +25,8 @@
 
 /* global defs */
 #define WWID_SIZE	64
-#define SERIAL_SIZE	15
+#define SERIAL_SIZE	17
+#define NODE_NAME_SIZE	19
 #define PATH_STR_SIZE   16
 #define PARAMS_SIZE	256
 #define FILE_NAME_SIZE	256
@@ -109,6 +110,7 @@ struct path {
 	char product_id[SCSI_PRODUCT_SIZE];
 	char rev[SCSI_REV_SIZE];
 	char serial[SERIAL_SIZE];
+	char tgt_node_name[NODE_NAME_SIZE];
 	unsigned long size;
 	int state;
 	int dmstate;
@@ -153,8 +155,8 @@ struct pathgroup {
 /* Build version */
 #define PROG    "multipath"
 
-#define VERSION_CODE 0x000309
-#define DATE_CODE    0x050c04
+#define VERSION_CODE 0x000401
+#define DATE_CODE    0x150c04
 
 #define MULTIPATH_VERSION(version)	\
 	(version >> 16) & 0xFF,		\
